@@ -38,7 +38,6 @@
 #include <gpe/errorbox.h>
 #include <gpe/question.h>
 #include <gpe/spacing.h>
-//#include <gpe/popup_menu.h>
 #include <xsettings-client.h>
 
 #define KEY_MATCHBOX "MATCHBOX/"
@@ -61,6 +60,9 @@ static struct
   GtkWidget *demolabel2;
   GtkWidget *spFS, *bFont, *bColorFont;
   GtkWidget *spFSApp, *bFontApp;
+  GtkWidget *slIconSize;
+  GtkWidget *slToolbarSize;
+  GtkWidget *cDefault;
 }
 self;
 
@@ -98,7 +100,6 @@ MBDesktopBG mb_back;
 static void select_font_popup (GtkWidget *parent_button);
 static void on_font_size_change(GtkSpinButton *spinbutton,GtkScrollType arg1);
 static GtkWidget *popup_menu_button_new (const gchar *stock_id);
-//static void on_font_select(char* desc);
 
 
 gboolean
@@ -204,25 +205,32 @@ mbbg_parse_spec(MBDesktopBG *mbbg, char *spec)
 void
 widget_set_color_rgb8 (GtkWidget * widget,float r, float g, float b)
 {
-//  static GdkColor white = {0,0xffff,0xffff,0xffff};
-//  static GdkColor black = {0,0x0000,0x0000,0x0000};
   GtkStyle *astyle;
   GtkRcStyle *rc_style;
   GdkColor gcolor;
   GtkBin bbin;
   float gray;
 
-  bbin =  (GtkBin)(GTK_BUTTON(widget)->bin);
-  gray = 0.3*r + 0.59*g + 0.11*b;
+  if (!GTK_IS_BUTTON(widget))
+  {
+	 fprintf(stderr,"no button... exiting\n");
+	 return;
+  }
   
+  bbin =  (GtkBin)(GTK_BUTTON(widget)->bin);
+
+  gray = 0.3*r + 0.59*g + 0.11*b;
+
+	
   if (gray > 0.5)
   {
-	  gtk_label_set_markup(GTK_LABEL(bbin.child),g_strdup_printf("<span foreground=\"#000000\"> %s </span>",_("Color")));
+	  gtk_label_set_markup(GTK_LABEL(bbin.child),
+	  	g_strdup_printf("<span foreground=\"#000000\"> %s </span>",gtk_label_get_text(GTK_LABEL(bbin.child))));
   }
   else
   {
-	  gtk_label_set_markup(GTK_LABEL(bbin.child),g_strdup_printf("<span foreground=\"#ffffff\"> %s </span>",_("Color")));
-
+	  gtk_label_set_markup(GTK_LABEL(bbin.child),
+	    g_strdup_printf("<span foreground=\"#ffffff\"> %s </span>",gtk_label_get_text(GTK_LABEL(bbin.child))));
   }
   gcolor.pixel = 0;
   gcolor.red = (int)(r*65534.0);
@@ -239,8 +247,6 @@ widget_set_color_rgb8 (GtkWidget * widget,float r, float g, float b)
       rc_style->color_flags[GTK_STATE_NORMAL] |= GTK_RC_FG;
       rc_style->color_flags[GTK_STATE_NORMAL] |= GTK_RC_BASE;
       rc_style->color_flags[GTK_STATE_NORMAL] |= GTK_RC_BG;
-//      rc_style->text[GTK_STATE_NORMAL] = xcolor;
-//      rc_style->color_flags[GTK_STATE_NORMAL] |= GTK_RC_TEXT;
 		
       gtk_widget_modify_style (widget, rc_style);
     }
@@ -293,7 +299,7 @@ sp_color_selector_update_sliders (SPColorSlider * csel1, guint channels)
   g = csel->a[1]->value;
   b = csel->a[2]->value;
 	
-  widget_set_color_rgb8(csel->previewbutton,r,g,b);
+  if (GTK_WIDGET_DRAWABLE(csel->previewbutton)) widget_set_color_rgb8(csel->previewbutton,r,g,b);
   updating = FALSE;
 }
 
@@ -306,41 +312,62 @@ sp_color_selector_update_sliders (SPColorSlider * csel1, guint channels)
 
 void update_enabled_widgets()
 {
-	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(self.rbSolid)))
-	{
-		gtk_widget_set_sensitive(self.bColor1,TRUE);
-		gtk_widget_set_sensitive(self.bColor2,FALSE);
-		gtk_widget_set_sensitive(self.eImage,FALSE);
-		gtk_widget_set_sensitive(self.bOpen,FALSE);
-		gtk_widget_set_sensitive(self.rbH,FALSE);
-		gtk_widget_set_sensitive(self.rbV,FALSE);
-		gtk_widget_set_sensitive(self.rbImgCent,FALSE);
-		gtk_widget_set_sensitive(self.rbImgStr,FALSE);
-		gtk_widget_set_sensitive(self.rbImgTiled,FALSE);
-	}
-	else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(self.rbGrad)))
-	{
-		gtk_widget_set_sensitive(self.bColor1,TRUE);
-		gtk_widget_set_sensitive(self.bColor2,TRUE);
-		gtk_widget_set_sensitive(self.eImage,FALSE);
-		gtk_widget_set_sensitive(self.bOpen,FALSE);
-		gtk_widget_set_sensitive(self.rbH,TRUE);
-		gtk_widget_set_sensitive(self.rbV,TRUE);
-		gtk_widget_set_sensitive(self.rbImgCent,FALSE);
-		gtk_widget_set_sensitive(self.rbImgStr,FALSE);
-		gtk_widget_set_sensitive(self.rbImgTiled,FALSE);
-	}
-	else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(self.rbImage)))
+	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(self.cDefault)))
 	{
 		gtk_widget_set_sensitive(self.bColor1,FALSE);
 		gtk_widget_set_sensitive(self.bColor2,FALSE);
-		gtk_widget_set_sensitive(self.eImage,TRUE);
-		gtk_widget_set_sensitive(self.bOpen,TRUE);
+		gtk_widget_set_sensitive(self.eImage,FALSE);
+		gtk_widget_set_sensitive(self.bOpen,FALSE);
 		gtk_widget_set_sensitive(self.rbH,FALSE);
 		gtk_widget_set_sensitive(self.rbV,FALSE);
-		gtk_widget_set_sensitive(self.rbImgCent,TRUE);
-		gtk_widget_set_sensitive(self.rbImgStr,TRUE);
-		gtk_widget_set_sensitive(self.rbImgTiled,TRUE);
+		gtk_widget_set_sensitive(self.rbImgCent,FALSE);
+		gtk_widget_set_sensitive(self.rbImgStr,FALSE);
+		gtk_widget_set_sensitive(self.rbImgTiled,FALSE);
+		gtk_widget_set_sensitive(self.rbSolid,FALSE);
+		gtk_widget_set_sensitive(self.rbGrad,FALSE);
+		gtk_widget_set_sensitive(self.rbImage,FALSE);
+	}
+	else
+	{
+		gtk_widget_set_sensitive(self.rbSolid,TRUE);
+		gtk_widget_set_sensitive(self.rbGrad,TRUE);
+		gtk_widget_set_sensitive(self.rbImage,TRUE);
+		if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(self.rbSolid)))
+		{
+			gtk_widget_set_sensitive(self.bColor1,TRUE);
+			gtk_widget_set_sensitive(self.bColor2,FALSE);
+			gtk_widget_set_sensitive(self.eImage,FALSE);
+			gtk_widget_set_sensitive(self.bOpen,FALSE);
+			gtk_widget_set_sensitive(self.rbH,FALSE);
+			gtk_widget_set_sensitive(self.rbV,FALSE);
+			gtk_widget_set_sensitive(self.rbImgCent,FALSE);
+			gtk_widget_set_sensitive(self.rbImgStr,FALSE);
+			gtk_widget_set_sensitive(self.rbImgTiled,FALSE);
+		}
+		else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(self.rbGrad)))
+		{
+			gtk_widget_set_sensitive(self.bColor1,TRUE);
+			gtk_widget_set_sensitive(self.bColor2,TRUE);
+			gtk_widget_set_sensitive(self.eImage,FALSE);
+			gtk_widget_set_sensitive(self.bOpen,FALSE);
+			gtk_widget_set_sensitive(self.rbH,TRUE);
+			gtk_widget_set_sensitive(self.rbV,TRUE);
+			gtk_widget_set_sensitive(self.rbImgCent,FALSE);
+			gtk_widget_set_sensitive(self.rbImgStr,FALSE);
+			gtk_widget_set_sensitive(self.rbImgTiled,FALSE);
+		}
+		else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(self.rbImage)))
+		{
+			gtk_widget_set_sensitive(self.bColor1,FALSE);
+			gtk_widget_set_sensitive(self.bColor2,FALSE);
+			gtk_widget_set_sensitive(self.eImage,TRUE);
+			gtk_widget_set_sensitive(self.bOpen,TRUE);
+			gtk_widget_set_sensitive(self.rbH,FALSE);
+			gtk_widget_set_sensitive(self.rbV,FALSE);
+			gtk_widget_set_sensitive(self.rbImgCent,TRUE);
+			gtk_widget_set_sensitive(self.rbImgStr,TRUE);
+			gtk_widget_set_sensitive(self.rbImgTiled,TRUE);
+		}
 	}
 }
 
@@ -373,7 +400,7 @@ build_colorbox ()
   gtk_table_set_col_spacings (GTK_TABLE (colorbox), gpe_boxspacing);
   gtk_widget_show (colorbox);
 
-	button = gtk_button_new();
+	button = gtk_button_new_with_label(" ");
 	csel->previewbutton = button;
     gtk_widget_set_size_request(button,30,30+6*gpe_boxspacing);
     gtk_table_attach (GTK_TABLE (colorbox), button, 2, 3, 0, 3,
@@ -450,6 +477,18 @@ notify_func (const char *name,
 		}
 	  }
     }
+   if (strncmp (name, KEY_GTK, strlen (KEY_GTK)) == 0)
+    {
+      char *p = (char *) name + strlen (KEY_GTK);
+
+ 	  if (!strcmp (p, "ToolbarIconSize"))
+	  {
+	  if (setting->type == XSETTINGS_TYPE_INT)
+	    {
+			gtk_range_set_value(GTK_RANGE(self.slToolbarSize),(float)setting->data.v_int);
+		}
+	  }
+    }
    if (strncmp (name, KEY_THEME, strlen (KEY_THEME)) == 0)
     {
       char *p = (char *) name + strlen (KEY_THEME);
@@ -472,6 +511,9 @@ notify_func (const char *name,
 	{
 	  if (setting->type == XSETTINGS_TYPE_STRING)
 	    {
+			if (strlen(setting->data.v_string) > 1) /* There is something defined */
+				  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(self.cDefault),FALSE);
+				
 			mbbg_parse_spec(&mb_back,g_strdup(setting->data.v_string));
 			  switch(mb_back.type)
 				{
@@ -481,14 +523,17 @@ notify_func (const char *name,
 				  break;
 				case BG_TILED_PXM:
 				  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(self.rbImgTiled),TRUE);
+				  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(self.rbImage),TRUE);
 				  gtk_entry_set_text(GTK_ENTRY(self.eImage),mb_back.data.filename);
 				  break;
    				case BG_CENTERED_PXM:
  				  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(self.rbImgCent),TRUE);
+				  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(self.rbImage),TRUE);
 				  gtk_entry_set_text(GTK_ENTRY(self.eImage),mb_back.data.filename);
 				  break;
 				case BG_STRETCHED_PXM:
  				  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(self.rbImgStr),TRUE);
+				  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(self.rbImage),TRUE);
 				  gtk_entry_set_text(GTK_ENTRY(self.eImage),mb_back.data.filename);
 				  break;
 				case BG_GRADIENT_HORIZ:
@@ -508,7 +553,16 @@ notify_func (const char *name,
  	    update_enabled_widgets();			
 	}
       
-	if (!strcmp (p, "DesktopFont"))
+	
+	if (!strcmp (p, "Desktop/IconSize"))
+	{
+	  if (setting->type == XSETTINGS_TYPE_INT)
+	    {
+			gtk_range_set_value(GTK_RANGE(self.slIconSize),(float)setting->data.v_int);
+		}
+	}
+	
+	if (!strcmp (p, "Desktop/Font"))
 	{
 	  if (setting->type == XSETTINGS_TYPE_STRING)
 	    {
@@ -526,7 +580,7 @@ notify_func (const char *name,
 		}
 	}
 	
-	if (!strcmp (p, "DesktopFontColor"))
+	if (!strcmp (p, "Desktop/FontColor"))
 	{
 	  if (setting->type == XSETTINGS_TYPE_STRING)
 	    {
@@ -637,7 +691,7 @@ on_color_select (GtkWidget * widget, GdkEvent * event)
 {
   GtkWidget *w;
   GtkStyle *astyle = gtk_widget_get_style(widget);
-
+	
   w = gtk_dialog_new_with_buttons (_("Select color"), GTK_WINDOW (mainw),
 				   GTK_DIALOG_MODAL |
 				   GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -664,7 +718,7 @@ static void
 File_Selected (char *file, gpointer data)
 {
   if (access(file,R_OK))
-	gpe_error_box(_("You don't have read access\nto selected background image!"));
+	gpe_error_box(_("You don't have read access to selected background image!"));
   else
 	gtk_entry_set_text (GTK_ENTRY (self.eImage), file);
 }
@@ -687,7 +741,7 @@ char* get_color_from_widget(GtkWidget* w)
   r = acolor.red >> 8;
   g = acolor.green >> 8;
   b = acolor.blue >> 8;
-  result = g_strdup_printf("#%02x%02x%02x",r,g,b);
+  result = g_strdup_printf("rgb:%02x/%02x/%02x",r,g,b);
   return result;
 }
 
@@ -702,61 +756,73 @@ Theme_Save ()
 	GtkWidget* label;
 	
     /* background settings */
-    if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(self.rbSolid)))
+	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(self.cDefault)))
 	{
-		par1 = get_color_from_widget(self.bColor1);
-		confstr = g_strdup_printf("col-solid:%s",par1);
-		free(par1);
+		confstr = NULL;
 	}
-	else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(self.rbGrad)))
-	{
-		par1 = get_color_from_widget(self.bColor1);
-		par2 = get_color_from_widget(self.bColor2);
-		if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(self.rbV)))
-			confstr = g_strdup_printf("col-gradient-vertical:%s,%s",par1,par2);
-		else
-			confstr = g_strdup_printf("col-gradient-horizontal:%s,%s",par1,par2);
-		free(par1);
-		free(par2);		
-	}
-	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(self.rbImage)))
-	{
-		par1 = gtk_editable_get_chars(GTK_EDITABLE(self.eImage),0,-1);
-		if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(self.rbImgCent)))
-			confstr = g_strdup_printf("img-centered:%s",par1);
-		else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(self.rbImgStr)))
-			confstr = g_strdup_printf("img-stretched:%s",par1);
-		else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(self.rbImgTiled)))
-			confstr = g_strdup_printf("img-tiled:%s",par1);
-		if (access(par1,R_OK))
+	else
+	{	
+		if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(self.rbSolid)))
 		{
-			gpe_error_box(_("You don't have read access\nto selected background image!"));
-			free(confstr);
-			confstr = NULL;
+			par1 = get_color_from_widget(self.bColor1);
+			confstr = g_strdup_printf("col-solid:%s",par1);
+			free(par1);
 		}
-		free(par1);
+		else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(self.rbGrad)))
+		{
+			par1 = get_color_from_widget(self.bColor1);
+			par2 = get_color_from_widget(self.bColor2);
+			if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(self.rbV)))
+				confstr = g_strdup_printf("col-gradient-vertical:%s,%s",par1,par2);
+			else
+				confstr = g_strdup_printf("col-gradient-horizontal:%s,%s",par1,par2);
+			free(par1);
+			free(par2);		
+		}
+		if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(self.rbImage)))
+		{
+			par1 = gtk_editable_get_chars(GTK_EDITABLE(self.eImage),0,-1);
+			if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(self.rbImgCent)))
+				confstr = g_strdup_printf("img-centered:%s",par1);
+			else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(self.rbImgStr)))
+				confstr = g_strdup_printf("img-stretched:%s",par1);
+			else if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(self.rbImgTiled)))
+				confstr = g_strdup_printf("img-tiled:%s",par1);
+			if (access(par1,R_OK))
+			{
+				gpe_error_box(_("You don't have read access to selected background image!"));
+				free(confstr);
+				confstr = NULL;
+			}
+			free(par1);
+		}
+	
 	}
-  	
+	
+	/* background style*/  	
 	if (confstr)
 	{
-		printf ("xst write %s%s str %s\n", KEY_MATCHBOX, "Background", confstr);
 		system_printf ("xst write %s%s str %s", KEY_MATCHBOX, "Background", confstr);
 		free(confstr);
 	}
-
+	else /* theme default - erase settings */
+	{
+		system_printf ("xst delete %s%s", KEY_MATCHBOX, "Background");
+	}
+			
 	/* desktop font type and size */
 	label = g_object_get_data (G_OBJECT (self.bFont), "label");
 	clabel = gtk_label_get_text(GTK_LABEL(label));
 	fs = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(self.spFS));
-	confstr = g_strdup_printf("xst write %s%s str \"%s-%i\"", KEY_MATCHBOX, "DesktopFont", clabel,fs);
-	printf ("xst write %s%s str \"%s-%i\"\n", KEY_MATCHBOX, "DesktopFont", clabel,fs);
+	confstr = g_strdup_printf("xst write %s%s str \"%s-%i\"", KEY_MATCHBOX, "Desktop/Font", clabel,fs);
 	system(confstr);
 	free(confstr);
-	/* font color */
+	
+	/* desktop font color */
 	confstr = get_color_from_widget(self.bColorFont);
-	printf ("xst write %s%s str \"%s\"\n", KEY_MATCHBOX, "DesktopFontColor", confstr);
-	system_printf ("xst write %s%s str \"%s\"", KEY_MATCHBOX, "DesktopFontColor", confstr);
+	system_printf ("xst write %s%s str %s", KEY_MATCHBOX, "Desktop/FontColor", confstr);
 	free(confstr);
+	
 	/* application font type and size */
 	label = g_object_get_data (G_OBJECT (self.bFontApp), "label");
 	clabel = gtk_label_get_text(GTK_LABEL(label));
@@ -764,6 +830,14 @@ Theme_Save ()
 	confstr = g_strdup_printf("xst write %s%s str \"%s %i\"", KEY_GTK, "FontName", clabel,fs);
 	system(confstr);
 	free(confstr);	
+
+	/* desktop icon size */
+	fs = (int)gtk_range_get_value(GTK_RANGE(self.slIconSize));
+	system_printf ("xst write %s%s int %d", KEY_MATCHBOX, "Desktop/IconSize", fs);
+	
+	/* desktop icon size */
+	fs = (int)gtk_range_get_value(GTK_RANGE(self.slToolbarSize));
+	system_printf ("xst write %s%s int %d", KEY_GTK, "ToolbarIconSize", fs);
 }
 
 void
@@ -815,7 +889,7 @@ Theme_Build_Objects ()
   gtk_table_set_row_spacings (GTK_TABLE (table), gpe_boxspacing);
   gtk_table_set_col_spacings (GTK_TABLE (table), gpe_boxspacing);
 
-  label = gtk_label_new("none");
+  label = gtk_label_new(NULL);
   gtk_misc_set_alignment(GTK_MISC(label),0.0,0.5);
   tstr = g_strdup_printf ("<b>%s</b>", _("Desktop Theme"));
   gtk_label_set_markup (GTK_LABEL (label), tstr);
@@ -833,7 +907,7 @@ Theme_Build_Objects ()
   gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, TRUE, 0);
 
   self.cbTheme = gtk_combo_new ();
-  themeitems = make_items_from_dir (matchboxpath);
+  themeitems = make_items_from_dir (matchboxpath,"matchbox");
   gtk_combo_set_popdown_strings (GTK_COMBO (self.cbTheme), themeitems);
   gtk_combo_set_value_in_list (GTK_COMBO (self.cbTheme), TRUE, FALSE);
   gtk_editable_set_editable (GTK_EDITABLE(GTK_COMBO(self.cbTheme)->entry), FALSE);
@@ -842,6 +916,38 @@ Theme_Build_Objects ()
 
   gtk_signal_connect (GTK_OBJECT (GTK_COMBO (self.cbTheme)->entry), "changed",
 		      GTK_SIGNAL_FUNC (on_matchbox_entry_changed), NULL);
+			  
+  label = gtk_label_new(NULL);
+  gtk_misc_set_alignment(GTK_MISC(label),0.0,0.9);
+  tstr = g_strdup_printf ("<b>%s</b>", _("Icon Size"));
+  gtk_label_set_markup (GTK_LABEL (label), tstr);
+  g_free (tstr);
+  gtk_table_attach (GTK_TABLE (table), label, 0, 2, 2, 3,
+		    (GtkAttachOptions) (table_attach_left_col_x),
+		    (GtkAttachOptions) (table_attach_left_col_y), 0, 0);
+  
+  self.slIconSize = gtk_hscale_new_with_range(16.0,64.0,2.0);
+  gtk_table_attach (GTK_TABLE (table), self.slIconSize, 0, 4, 3, 4,
+		    (GtkAttachOptions) (table_attach_left_col_x),
+		    (GtkAttachOptions) (table_attach_left_col_y), 0, 0);
+  gtk_range_set_value(GTK_RANGE(self.slIconSize),32.0);  
+  gtk_range_set_increments(GTK_RANGE(self.slIconSize),2.0,4.0);
+  
+  label = gtk_label_new(NULL);
+  gtk_misc_set_alignment(GTK_MISC(label),0.0,0.9);
+  tstr = g_strdup_printf ("<b>%s</b>", _("Toolbar Icon Size"));
+  gtk_label_set_markup (GTK_LABEL (label), tstr);
+  g_free (tstr);
+  gtk_table_attach (GTK_TABLE (table), label, 0, 2, 4, 5,
+		    (GtkAttachOptions) (table_attach_left_col_x),
+		    (GtkAttachOptions) (table_attach_left_col_y), 0, 0);
+  
+  self.slToolbarSize = gtk_hscale_new_with_range(1.0,3.0,1.0);
+  gtk_table_attach (GTK_TABLE (table), self.slToolbarSize, 0, 4, 5, 6,
+		    (GtkAttachOptions) (table_attach_left_col_x),
+		    (GtkAttachOptions) (table_attach_left_col_y), 0, 0);
+  gtk_range_set_value(GTK_RANGE(self.slToolbarSize),2.0);  
+  gtk_range_set_increments(GTK_RANGE(self.slToolbarSize),1.0,1.0);
  /*---------------------------------------------*/
 
   label = gtk_label_new (_("Background"));
@@ -862,18 +968,25 @@ Theme_Build_Objects ()
 		    (GtkAttachOptions) (table_attach_left_col_x),
 		    (GtkAttachOptions) (table_attach_left_col_y), 0, 0);
 
+  self.cDefault = gtk_check_button_new_with_label(_("Theme Default"));
+  gtk_table_attach (GTK_TABLE (table), self.cDefault, 0, 2, 1, 2,
+		    (GtkAttachOptions) (table_attach_left_col_x),
+		    (GtkAttachOptions) (table_attach_left_col_y), 0, 0);
+  g_signal_connect (GTK_OBJECT (self.cDefault), "toggled",
+		       (update_enabled_widgets), NULL);
+			
   label = gtk_radio_button_new_with_label (NULL, _("Solid color"));
   rg_background = label;
   self.rbSolid = label;
   g_signal_connect (GTK_OBJECT (label), "toggled",
 		       (update_enabled_widgets), NULL);
-  gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2,
+  gtk_table_attach (GTK_TABLE (table), label, 0, 1, 2, 3,
 		    (GtkAttachOptions) (table_attach_left_col_x),
 		    (GtkAttachOptions) (table_attach_left_col_y), 0, 0);
 			
   // box for radio buttons
   hbox = gtk_hbox_new(FALSE,gpe_boxspacing);
-  gtk_table_attach (GTK_TABLE (table), hbox, 0, 3, 5, 6,
+  gtk_table_attach (GTK_TABLE (table), hbox, 0, 3, 6, 7,
 		    (GtkAttachOptions) (table_attach_left_col_x),
 		    (GtkAttachOptions) (table_attach_left_col_y), 0, 0);
   label = gtk_radio_button_new_with_label (NULL, _("Horizontal"));
@@ -886,10 +999,9 @@ Theme_Build_Objects ()
   
   self.bColor1 = gtk_button_new();
   gtk_button_set_label(GTK_BUTTON(self.bColor1),_("Color"));
-  //gtk_button_new_from_stock (GTK_STOCK_SELECT_COLOR);
   g_signal_connect (GTK_OBJECT (self.bColor1), "clicked",
 		    G_CALLBACK (on_color_select), NULL);
-  gtk_table_attach (GTK_TABLE (table), self.bColor1, 1, 2, 1, 2,
+  gtk_table_attach (GTK_TABLE (table), self.bColor1, 1, 2, 2, 3,
 		    (GtkAttachOptions) (table_attach_left_col_x),
 		    (GtkAttachOptions) (table_attach_left_col_y), 0, 0);
 
@@ -900,7 +1012,7 @@ Theme_Build_Objects ()
   g_signal_connect (GTK_OBJECT (label), "toggled",
 		       (update_enabled_widgets), NULL);
   self.rbGrad = label;
-  gtk_table_attach (GTK_TABLE (table), label, 0, 1, 2, 3,
+  gtk_table_attach (GTK_TABLE (table), label, 0, 1, 3, 4,
 		    (GtkAttachOptions) (table_attach_left_col_x),
 		    (GtkAttachOptions) (table_attach_left_col_y), 0, 0);
 
@@ -908,8 +1020,8 @@ Theme_Build_Objects ()
   gtk_button_set_label(GTK_BUTTON(self.bColor2),_("Color"));
   g_signal_connect (GTK_OBJECT (self.bColor2), "clicked",
 		    G_CALLBACK (on_color_select), NULL);
-  //gtk_button_new_from_stock (GTK_STOCK_SELECT_COLOR);
-  gtk_table_attach (GTK_TABLE (table), self.bColor2, 1, 2, 2, 3,
+			
+  gtk_table_attach (GTK_TABLE (table), self.bColor2, 1, 2, 3, 4,
 		    (GtkAttachOptions) (table_attach_left_col_x),
 		    (GtkAttachOptions) (table_attach_left_col_y), 0, 0);
 
@@ -920,12 +1032,12 @@ Theme_Build_Objects ()
   g_signal_connect (GTK_OBJECT (label), "toggled",
 		       (update_enabled_widgets), NULL);
   self.rbImage = label;
-  gtk_table_attach (GTK_TABLE (table), label, 0, 1, 6, 7,
+  gtk_table_attach (GTK_TABLE (table), label, 0, 1, 7, 8,
 		    (GtkAttachOptions) (table_attach_left_col_x),
 		    (GtkAttachOptions) (table_attach_left_col_y), 0, 0);
 
   self.eImage = gtk_entry_new ();
-  gtk_table_attach (GTK_TABLE (table), self.eImage, 0, 1, 7, 8,
+  gtk_table_attach (GTK_TABLE (table), self.eImage, 0, 1, 8, 9,
 		    (GtkAttachOptions) (table_attach_left_col_x),
 		    (GtkAttachOptions) (table_attach_left_col_y), 0, 0);
   gtk_widget_set_size_request (self.eImage, 150, -1);
@@ -933,12 +1045,12 @@ Theme_Build_Objects ()
   self.bOpen = gtk_button_new_from_stock (GTK_STOCK_OPEN);
   gtk_signal_connect (GTK_OBJECT (self.bOpen), "pressed",
 		      GTK_SIGNAL_FUNC (choose_file), NULL);
-  gtk_table_attach (GTK_TABLE (table), self.bOpen, 1, 2, 7, 8,
+  gtk_table_attach (GTK_TABLE (table), self.bOpen, 1, 2, 8, 9,
 		    (GtkAttachOptions) (table_attach_left_col_x),
 		    (GtkAttachOptions) (table_attach_left_col_y), 0, 0);
 
   hbox = gtk_hbox_new(False,gpe_boxspacing);
-  gtk_table_attach (GTK_TABLE (table), hbox, 0, 3, 8, 9,
+  gtk_table_attach (GTK_TABLE (table), hbox, 0, 3, 9, 10,
 		    (GtkAttachOptions) (table_attach_left_col_x),
 		    (GtkAttachOptions) (table_attach_left_col_y), 0, 0);
 			
@@ -954,14 +1066,14 @@ Theme_Build_Objects ()
   gtk_box_pack_start(GTK_BOX(hbox),label,FALSE,TRUE,0);
 			
  /*---------------------------------------------*/
-  label = gtk_label_new (_("Font"));
+  label = gtk_label_new (_("Fonts"));
   table = gtk_table_new (2, 2, FALSE);
   gtk_notebook_append_page(GTK_NOTEBOOK(notebook),table,label);
   gtk_container_set_border_width (GTK_CONTAINER (table), gpe_border);
   gtk_table_set_row_spacings (GTK_TABLE (table), gpe_boxspacing);
   gtk_table_set_col_spacings (GTK_TABLE (table), gpe_boxspacing);
  
-  label = gtk_label_new("none");
+  label = gtk_label_new(NULL);
   gtk_misc_set_alignment(GTK_MISC(label),0.0,0.5);
   tstr = g_strdup_printf ("<b>%s</b>", _("Desktop Font"));
   gtk_label_set_markup (GTK_LABEL (label), tstr);
@@ -995,7 +1107,8 @@ Theme_Build_Objects ()
   gtk_table_attach (GTK_TABLE (table), label, 1, 2, 1, 2,
 		    (GtkAttachOptions) (table_attach_left_col_x),
 		    (GtkAttachOptions) (table_attach_left_col_y), gpe_boxspacing, 0);
-  self.spFS = gtk_spin_button_new_with_range(1,20,1);
+  self.spFS = gtk_spin_button_new_with_range(5,20,1);
+  gtk_spin_button_set_value(GTK_SPIN_BUTTON(self.spFS),8.0);
   gtk_table_attach (GTK_TABLE (table), self.spFS, 1, 2, 2, 3,
 		    (GtkAttachOptions) (table_attach_left_col_x),
 		    (GtkAttachOptions) (table_attach_left_col_y), gpe_boxspacing, 0);
@@ -1016,7 +1129,7 @@ Theme_Build_Objects ()
   
  /*---------------------------------------------*/
  
-  label = gtk_label_new("none");
+  label = gtk_label_new(NULL);
   gtk_misc_set_alignment(GTK_MISC(label),0.0,0.5);
   tstr = g_strdup_printf ("<b>%s</b>", _("Application Font"));
   gtk_label_set_markup (GTK_LABEL (label), tstr);
@@ -1050,7 +1163,8 @@ Theme_Build_Objects ()
   gtk_table_attach (GTK_TABLE (table), label, 1, 2, 5, 6,
 		    (GtkAttachOptions) (table_attach_left_col_x),
 		    (GtkAttachOptions) (table_attach_left_col_y), gpe_boxspacing, 0);
-  self.spFSApp = gtk_spin_button_new_with_range(1,20,1);
+  self.spFSApp = gtk_spin_button_new_with_range(5,20,1);
+  gtk_spin_button_set_value(GTK_SPIN_BUTTON(self.spFSApp),8.0);
   gtk_table_attach (GTK_TABLE (table), self.spFSApp, 1, 2, 6, 7,
 		    (GtkAttachOptions) (table_attach_left_col_x),
 		    (GtkAttachOptions) (table_attach_left_col_y), gpe_boxspacing, 0);
@@ -1068,6 +1182,7 @@ Theme_Build_Objects ()
   gtk_label_set_text(GTK_LABEL(label),"Sans");	
   label = g_object_get_data (G_OBJECT (self.bFontApp), "label");
   gtk_label_set_text(GTK_LABEL(label),"Sans");	
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(self.cDefault),TRUE);
   
   mb_start_xsettings ();
 
@@ -1124,6 +1239,8 @@ on_font_select_desk(GtkWidget * widget, gpointer style)
 	pango_font_description_set_size(GTK_RC_STYLE(style)->font_desc,gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(self.spFS))*PANGO_SCALE);
 	label = g_object_get_data(G_OBJECT(self.bFont),"label");
 	gtk_label_set_text(GTK_LABEL(label),pango_font_description_get_family(GTK_RC_STYLE(style)->font_desc));	
+	select_font_popup(self.bFont);
+	on_font_size_change(self.spFS,GTK_SCROLL_NONE);
 }
 
 static void
@@ -1134,21 +1251,10 @@ on_font_select_app(GtkWidget * widget, gpointer style)
 	pango_font_description_set_size(GTK_RC_STYLE(style)->font_desc,gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(self.spFSApp))*PANGO_SCALE);
 	label = g_object_get_data(G_OBJECT(self.bFontApp),"label");
 	gtk_label_set_text(GTK_LABEL(label),pango_font_description_get_family(GTK_RC_STYLE(style)->font_desc));	
+	select_font_popup(self.bFontApp);
+	on_font_size_change(self.spFSApp,GTK_SCROLL_NONE);
 }
 
-/*
-static void
-on_font_select(char* desc)
-{
-	GtkRcStyle *astyle = gtk_rc_style_new();
-printf("cb %s\n",desc);
-    astyle->font_desc = pango_font_description_from_string (desc);
-	pango_font_description_set_size(GTK_RC_STYLE(astyle)->font_desc,gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(self.spFS))*PANGO_SCALE);
-    gtk_widget_modify_style (self.demolabel, astyle);
-//	label = g_object_get_data(G_OBJECT(self.bFont),"label");
-//	gtk_label_set_text(GTK_LABEL(label),pango_font_description_get_family(GTK_RC_STYLE(style)->font_desc));	
-}
-*/
 
 static void
 on_font_size_change(GtkSpinButton *spinbutton,GtkScrollType arg1)
@@ -1195,7 +1301,7 @@ select_font_popup (GtkWidget *parent_button)
   gint screen_height;
 
   parent_arrow = g_object_get_data (G_OBJECT (parent_button), "arrow");
-  if (g_object_get_data (G_OBJECT (parent_button), "active") == TRUE)
+  if ((gboolean)g_object_get_data (G_OBJECT (parent_button), "active") == TRUE)
   {
     gtk_widget_destroy (g_object_get_data (G_OBJECT (parent_button), "window"));
     g_object_set_data (G_OBJECT (parent_button), "active", FALSE);
@@ -1203,7 +1309,7 @@ select_font_popup (GtkWidget *parent_button)
   }
   else
   {
-    g_object_set_data (G_OBJECT (parent_button), "active", TRUE);
+    g_object_set_data (G_OBJECT (parent_button), "active", (gpointer)TRUE);
     gtk_arrow_set (GTK_ARROW (parent_arrow), GTK_ARROW_UP, GTK_SHADOW_NONE);
 
     popup_window = gtk_window_new (GTK_WINDOW_POPUP);
